# douyin_image [![Version][version-badge]][version-link] ![MIT License][license-badge]


Add douyin effect to image


`douyin_image` 是一个给图片添加抖音效果的库


### 示例

原图

![](https://raw.githubusercontent.com/pythonml/douyin_image/master/orig.jpeg)

转换后的代码图片

![](https://raw.githubusercontent.com/pythonml/douyin_image/master/out.jpeg)


### 使用方式

```
usage: douyin_image [-h] [--image IMAGEFILE] [--out OUTIMAGE]

optional arguments:
  -h, --help         show this help message and exit
  --image IMAGEFILE  path of image to add effect
  --out OUTIMAGE     path of output image
```


### 安装

```
$ pip install douyin_image
```


### License

[MIT](https://github.com/pythonml/douyin_image/blob/master/LICENSE)


[version-badge]:   https://img.shields.io/badge/version-0.1-brightgreen.svg
[version-link]:    https://pypi.python.org/pypi/douyin_image/
[license-badge]:   https://img.shields.io/github/license/pythonml/douyin_image.svg
add notice copy content ,only test